@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-x86.h"
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux 4.15-rc7 */
 const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "_llseek", 140 },
 	{ "_newselect", 142 },
@@ -41,7 +41,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "alarm", 27 },
 	{ "arm_fadvise64_64", __PNR_arm_fadvise64_64 },
 	{ "arm_sync_file_range", __PNR_arm_sync_file_range },
-	{ "arch_prctl", __PNR_arch_prctl },
+	{ "arch_prctl", 384 },
 	{ "bdflush", 134 },
 	{ "bind", 361 },
 	{ "bpf", 357 },
@@ -122,6 +122,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "get_mempolicy", 275 },
 	{ "get_robust_list", 312 },
 	{ "get_thread_area", 244 },
+	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", 318 },
 	{ "getcwd", 183 },
 	{ "getdents", 141 },
@@ -304,9 +305,11 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "rt_sigtimedwait", 177 },
 	{ "rt_tgsigqueueinfo", 335 },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
 	{ "s390_pci_mmio_read", __PNR_s390_pci_mmio_read },
 	{ "s390_pci_mmio_write", __PNR_s390_pci_mmio_write },
 	{ "s390_runtime_instr", __PNR_s390_runtime_instr },
+	{ "s390_sthyi", __PNR_s390_sthyi },
 	{ "sched_get_priority_max", 159 },
 	{ "sched_get_priority_min", 160 },
 	{ "sched_getaffinity", 242 },
@@ -392,6 +395,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "stat64", 195 },
 	{ "statfs", 99 },
 	{ "statfs64", 268 },
+	{ "statx", 383 },
 	{ "stime", 25 },
 	{ "stty", 31 },
 	{ "subpage_prot", __PNR_subpage_prot },
